@@ -22,7 +22,7 @@ fn main() -> Result<(), Box<dyn Error>> {
     let mut output_file = File::create("outputs_versions.log").unwrap();
     while let Some(block_extra) = recv.recv()? {
         log!(
-            periodic_log_level(block_extra.height),
+            periodic_log_level(block_extra.height, 10_000),
             "# {:7} {} counters:{:?}",
             block_extra.height,
             block_extra.block_hash,
