@@ -1,56 +1,27 @@
-use crate::truncmap::TruncMap;
+use crate::utxo::UtxoStore;
 use crate::BlockExtra;
-use bitcoin::{OutPoint, Script, Transaction, TxOut, Txid};
+use bitcoin::{OutPoint, Script, TxOut};
 use log::{debug, info, trace};
 use std::sync::mpsc::Receiver;
 use std::sync::mpsc::SyncSender;
 use std::time::Instant;
 
-pub struct Fee {
+pub struct Fee<T: UtxoStore> {
     receiver: Receiver<Option<BlockExtra>>,
     sender: SyncSender<Option<BlockExtra>>,
-    utxo: Utxo,
+    utxo: T,
 }
 
-struct Utxo {
-    map: TruncMap,
-    unspendable: u64,
-}
-
-impl Utxo {
-    pub fn new() -> Self {
-        Utxo {
-            map: TruncMap::default(),
-            unspendable: 0,
-        }
-    }
-
-    pub fn add(&mut self, tx: &Transaction) -> Txid {
-        let txid = tx.txid();
-        for (i, output) in tx.output.iter().enumerate() {
-            if output.script_pubkey.is_provably_unspendable() {
-                self.unspendable += 1;
-                continue;
-            }
-            self.map.insert(OutPoint::new(txid, i as u32), output);
-        }
-        txid
-    }
-
-    pub fn remove(&mut self, outpoint: OutPoint) -> TxOut {
-        self.map.remove(&outpoint).unwrap()
-    }
-}
-
-impl Fee {
+impl<T: UtxoStore> Fee<T> {
     pub fn new(
         receiver: Receiver<Option<BlockExtra>>,
         sender: SyncSender<Option<BlockExtra>>,
-    ) -> Fee {
+        utxo: T,
+    ) -> Fee<T> {
         Fee {
             sender,
             receiver,
-            utxo: Utxo::new(),
+            utxo,
         }
     }
 
@@ -71,22 +42,18 @@ impl Fee {
                     total_txs += block_extra.block.txdata.len() as u64;
 
                     if block_extra.height % 10_000 == 0 {
-                        let (utxo_size, collision_size, utxo_capacity) = self.utxo.map.len();
-                        info!(
-                            "(utxo, collision, capacity): {:?} load:{:.1}% script on stack: {:.1}% unspendable:{}",
-                            (utxo_size, collision_size, utxo_capacity),
-                            (utxo_size as f64 / utxo_capacity as f64) * 100.0,
-                            self.utxo.map.script_on_stack() * 100.0,
-                            self.utxo.unspendable,
-                        );
-                    }
-                    for tx in block_extra.block.txdata.iter() {
-                        self.utxo.add(tx);
+                        info!("{}", self.utxo.stat());
                     }
 
+                    let mut prevouts = self
+                        .utxo
+                        .add_outputs_get_inputs(&block_extra.block, block_extra.height);
+                    let mut prevouts = prevouts.drain(..);
+
                     for tx in block_extra.block.txdata.iter().skip(1) {
                         for input in tx.input.iter() {
-                            let previous_txout = self.utxo.remove(input.previous_output);
+                            let previous_txout = prevouts.next().unwrap();
+
                             block_extra
                                 .outpoint_values
                                 .insert(input.previous_output, previous_txout);
